@@ -17,12 +17,12 @@
 
 #pragma once
 
-#include "src/capture/widgets/capturebutton.h"
+#include "src/widgets/capture/capturebutton.h"
 #include <QListWidget>
 
 class ButtonListView : public QListWidget {
 public:
-    ButtonListView(QWidget *parent= nullptr);
+    explicit ButtonListView(QWidget *parent= nullptr);
 
 public slots:
     void selectAll();
@@ -39,5 +39,4 @@ private:
     QMap<QString, CaptureButton::ButtonType> m_buttonTypeByName;
 
     void updateActiveButtons(QListWidgetItem *);
-
 };
