@@ -20,13 +20,12 @@
 #include <QtDBus/QDBusAbstractAdaptor>
 #include "src/core/controller.h"
 
-class FlameshotDBusAdapter : public QDBusAbstractAdaptor
-{
+class FlameshotDBusAdapter : public QDBusAbstractAdaptor {
     Q_OBJECT
     Q_CLASSINFO("D-Bus Interface", "org.dharkael.Flameshot")
 
 public:
-    FlameshotDBusAdapter(QObject *parent = nullptr);
+    explicit FlameshotDBusAdapter(QObject *parent = nullptr);
     virtual ~FlameshotDBusAdapter();
 
 signals:
@@ -36,7 +35,11 @@ signals:
 public slots:
     Q_NOREPLY void graphicCapture(QString path, int delay, uint id);
     Q_NOREPLY void fullScreen(QString path, bool toClipboard, int delay, uint id);
+    Q_NOREPLY void captureScreen(int number, QString path, bool toClipboard, int delay, uint id);
     Q_NOREPLY void openConfig();
     Q_NOREPLY void trayIconEnabled(bool enabled);
+    Q_NOREPLY void autostartEnabled(bool enabled);
 
+private slots:
+    void handleCaptureTaken(uint id, const QPixmap &p);
 };
