@@ -23,7 +23,7 @@
 class GlobalShortcutFilter : public QObject, public QAbstractNativeEventFilter {
     Q_OBJECT
 public:
-    explicit GlobalShortcutFilter(QObject *parent = 0);
+    explicit GlobalShortcutFilter(QObject *parent = nullptr);
 
     bool nativeEventFilter(const QByteArray &eventType, void *message, long *result);
 
@@ -35,5 +35,4 @@ private:
     quint32 nativeKeycode(Qt::Key key);
     bool registerShortcut(quint32 nativeKey, quint32 nativeMods);
     bool unregisterShortcut(quint32 nativeKey, quint32 nativeMods);
-
 };
