@@ -22,13 +22,14 @@
 #include "src/cli/commandlineparser.h"
 #include "src/utils/systemnotification.h"
 #include "src/utils/pathinfo.h"
+#include "src/core/capturerequest.h"
 #include <QApplication>
 #include <QTranslator>
 #include <QTextStream>
 #include <QTimer>
 #include <QDir>
 
-#ifdef Q_OS_LINUX
+#if defined(Q_OS_LINUX) || defined(Q_OS_UNIX)
 #include "src/core/flameshotdbusadapter.h"
 #include "src/utils/dbusutils.h"
 #include <QDBusMessage>
@@ -46,10 +47,10 @@ int main(int argc, char *argv[]) {
         SingleApplication app(argc, argv);
 
         QTranslator translator;
-        QStringList trPaths = PathInfo::translations();
-        bool match = false;
+        QStringList trPaths = PathInfo::translationsPaths();
+
         for (const QString &path: trPaths) {
-            match = translator.load(QLocale::system().language(),
+            bool match = translator.load(QLocale(),
                                     "Internationalization", "_",
                                     path);
             if (match) {
@@ -62,8 +63,8 @@ int main(int argc, char *argv[]) {
         app.setApplicationName("flameshot");
         app.setOrganizationName("Dharkael");
 
-#ifdef Q_OS_LINUX
         auto c = Controller::getInstance();
+#if defined(Q_OS_LINUX) || defined(Q_OS_UNIX)
         new FlameshotDBusAdapter(c);
         QDBusConnection dbus = QDBusConnection::sessionBus();
         if (!dbus.isConnected()) {
@@ -72,10 +73,10 @@ int main(int argc, char *argv[]) {
         }
         dbus.registerObject("/", c);
         dbus.registerService("org.dharkael.Flameshot");
-#else
-        // Create inicial static instance
-        Controller::getInstance();
 #endif
+        // Exporting captures must be connected after the dbus interface
+        // or the dbus signal gets blocked until we end the exports.
+        c->enableExports();
         return app.exec();
     }
 
@@ -96,6 +97,7 @@ int main(int argc, char *argv[]) {
     CommandArgument fullArgument("full", "Capture the entire desktop.");
     CommandArgument guiArgument("gui", "Start a manual capture in GUI mode.");
     CommandArgument configArgument("config", "Configure flameshot.");
+    CommandArgument screenArgument("screen", "Capture a single screen.");
 
     // Options
     CommandOption pathOption(
@@ -117,6 +119,10 @@ int main(int argc, char *argv[]) {
                 {"t", "trayicon"},
                 "Enable or disable the trayicon",
                 "bool");
+    CommandOption autostartOption(
+                {"a", "autostart"},
+                "Enable or disable run at startup",
+                "bool");
     CommandOption showHelpOption(
                 {"s", "showhelp"},
                 "Show the help message in the capture mode",
@@ -132,6 +138,10 @@ int main(int argc, char *argv[]) {
     CommandOption rawImageOption(
                 {"r", "raw"},
                 "Print raw PNG capture");
+    CommandOption screenNumberOption(
+                {"n", "number"},
+                "Define the screen to capture,\ndefault: screen containing the cursor",
+                "Screen number", "-1");
 
     // Add checkers
     auto colorChecker = [&parser](const QString &colorCode) -> bool {
@@ -147,7 +157,8 @@ int main(int argc, char *argv[]) {
                        "You may need to escape the '#' sign as in '\\#FFF'";
 
     const QString delayErr = "Invalid delay, it must be higher than 0";
-    auto delayChecker = [&parser](const QString &delayValue) -> bool {
+    const QString numberErr = "Invalid screen number, it must be non negative";
+    auto numericChecker = [&parser](const QString &delayValue) -> bool {
         int value = delayValue.toInt();
         return value >= 0;
     };
@@ -168,22 +179,29 @@ int main(int argc, char *argv[]) {
 
     contrastColorOption.addChecker(colorChecker, colorErr);
     mainColorOption.addChecker(colorChecker, colorErr);
-    delayOption.addChecker(delayChecker, delayErr);
+    delayOption.addChecker(numericChecker, delayErr);
     pathOption.addChecker(pathChecker, pathErr);
     trayOption.addChecker(booleanChecker, booleanErr);
+    autostartOption.addChecker(booleanChecker, booleanErr);
     showHelpOption.addChecker(booleanChecker, booleanErr);
+    screenNumberOption.addChecker(numericChecker, numberErr);
 
     // Relationships
     parser.AddArgument(guiArgument);
+    parser.AddArgument(screenArgument);
     parser.AddArgument(fullArgument);
     parser.AddArgument(configArgument);
     auto helpOption = parser.addHelpOption();
     auto versionOption = parser.addVersionOption();
     parser.AddOptions({ pathOption, delayOption, rawImageOption }, guiArgument);
+    parser.AddOptions({ screenNumberOption, clipboardOption,pathOption,
+                        delayOption, rawImageOption },
+                      screenArgument);
     parser.AddOptions({ pathOption, clipboardOption, delayOption, rawImageOption },
                       fullArgument);
-    parser.AddOptions({ filenameOption, trayOption, showHelpOption,
-                        mainColorOption, contrastColorOption }, configArgument);
+    parser.AddOptions({ autostartOption, filenameOption, trayOption,
+                        showHelpOption, mainColorOption, contrastColorOption },
+                      configArgument);
     // Parse
     if (!parser.parse(app.arguments())) {
         goto finish;
@@ -197,30 +215,22 @@ int main(int argc, char *argv[]) {
         QString pathValue = parser.value(pathOption);
         int delay = parser.value(delayOption).toInt();
         bool isRaw = parser.isSet(rawImageOption);
-        uint id = qHash(app.arguments().join(" "));
-        DBusUtils utils(id);
+        DBusUtils dbusUtils;
+        CaptureRequest req(CaptureRequest::GRAPHICAL_MODE, delay, pathValue);
+        uint id = req.id();
 
         // Send message
         QDBusMessage m = QDBusMessage::createMethodCall("org.dharkael.Flameshot",
                                            "/", "", "graphicCapture");
         m << pathValue << delay << id;
         QDBusConnection sessionBus = QDBusConnection::sessionBus();
-        utils.checkDBusConnection(sessionBus);
+        dbusUtils.checkDBusConnection(sessionBus);
         sessionBus.call(m);
 
         if (isRaw) {
-            // captureTaken
-            sessionBus.connect("org.dharkael.Flameshot",
-                               "/", "", "captureTaken",
-                               &utils,
-                               SLOT(captureTaken(uint, QByteArray)));
-            // captureFailed
-            sessionBus.connect("org.dharkael.Flameshot",
-                               "/", "", "captureFailed",
-                               &utils,
-                               SLOT(captureFailed(uint)));
+            dbusUtils.connectPrintCapture(sessionBus, id);
             QTimer t;
-            t.setInterval(1000 * 60 * 15); // 15 minutes timeout
+            t.setInterval(delay + 1000 * 60 * 15); // 15 minutes timeout
             QObject::connect(&t, &QTimer::timeout, qApp,
                              &QCoreApplication::quit);
             t.start();
@@ -235,36 +245,89 @@ int main(int argc, char *argv[]) {
         bool isRaw = parser.isSet(rawImageOption);
         // Not a valid command
         if (!isRaw && !toClipboard && pathValue.isEmpty()) {
-            QTextStream(stdout) << "you have to set a valid flag:\n\n";
+            QTextStream out(stdout);
+            out << "Invalid format, set where to save the content with one of "
+                << "the following flags:\n "
+                << pathOption.dashedNames().join(", ") << "\n "
+                << rawImageOption.dashedNames().join(", ") << "\n "
+                << clipboardOption.dashedNames().join(", ") << "\n\n";
             parser.parse(QStringList() << argv[0] << "full" << "-h");
             goto finish;
         }
 
-        uint id = qHash(app.arguments().join(" "));
-        DBusUtils utils(id);
+        CaptureRequest req(CaptureRequest::FULLSCREEN_MODE, delay, pathValue);
+        if (toClipboard) {
+            req.addTask(CaptureRequest::CLIPBOARD_SAVE_TASK);
+        }
+        if (!pathValue.isEmpty()) {
+            req.addTask(CaptureRequest::FILESYSTEM_SAVE_TASK);
+        }
+        uint id = req.id();
+        DBusUtils dbusUtils;
 
         // Send message
         QDBusMessage m = QDBusMessage::createMethodCall("org.dharkael.Flameshot",
                                                "/", "", "fullScreen");
         m << pathValue << toClipboard << delay << id;
         QDBusConnection sessionBus = QDBusConnection::sessionBus();
-        utils.checkDBusConnection(sessionBus);
+        dbusUtils.checkDBusConnection(sessionBus);
         sessionBus.call(m);
 
         if (isRaw) {
-            // captureTaken
-            sessionBus.connect("org.dharkael.Flameshot",
-                               "/", "", "captureTaken",
-                               &utils,
-                               SLOT(captureTaken(uint, QByteArray)));
-            // captureFailed
-            sessionBus.connect("org.dharkael.Flameshot",
-                               "/", "", "captureFailed",
-                               &utils,
-                               SLOT(captureFailed(uint)));
+            dbusUtils.connectPrintCapture(sessionBus, id);
             // timeout just in case
             QTimer t;
-            t.setInterval(2000);
+            t.setInterval(delay + 2000);
+            QObject::connect(&t, &QTimer::timeout, qApp,
+                             &QCoreApplication::quit);
+            t.start();
+            // wait
+            app.exec();
+        }
+    }
+    else if (parser.isSet(screenArgument)) { // SCREEN
+        QString numberStr = parser.value(screenNumberOption);
+        int number = numberStr.startsWith("-") ? -1 : numberStr.toInt();
+        QString pathValue = parser.value(pathOption);
+        int delay = parser.value(delayOption).toInt();
+        bool toClipboard = parser.isSet(clipboardOption);
+        bool isRaw = parser.isSet(rawImageOption);
+        // Not a valid command
+        if (!isRaw && !toClipboard && pathValue.isEmpty()) {
+            QTextStream out(stdout);
+            out << "Invalid format, set where to save the content with one of "
+                << "the following flags:\n "
+                << pathOption.dashedNames().join(", ") << "\n "
+                << rawImageOption.dashedNames().join(", ") << "\n "
+                << clipboardOption.dashedNames().join(", ") << "\n\n";
+            parser.parse(QStringList() << argv[0] << "screen" << "-h");
+            goto finish;
+        }
+
+        CaptureRequest req(CaptureRequest::SCREEN_MODE,
+                           delay, pathValue, number);
+        if (toClipboard) {
+            req.addTask(CaptureRequest::CLIPBOARD_SAVE_TASK);
+        }
+        if (!pathValue.isEmpty()) {
+            req.addTask(CaptureRequest::FILESYSTEM_SAVE_TASK);
+        }
+        uint id = req.id();
+        DBusUtils dbusUtils;
+
+        // Send message
+        QDBusMessage m = QDBusMessage::createMethodCall("org.dharkael.Flameshot",
+                                               "/", "", "captureScreen");
+        m << number << pathValue << toClipboard << delay << id;
+        QDBusConnection sessionBus = QDBusConnection::sessionBus();
+        dbusUtils.checkDBusConnection(sessionBus);
+        sessionBus.call(m);
+
+        if (isRaw) {
+            dbusUtils.connectPrintCapture(sessionBus, id);
+            // timeout just in case
+            QTimer t;
+            t.setInterval(delay + 2000);
             QObject::connect(&t, &QTimer::timeout, qApp,
                              &QCoreApplication::quit);
             t.start();
@@ -273,6 +336,7 @@ int main(int argc, char *argv[]) {
         }
     }
     else if (parser.isSet(configArgument)) { // CONFIG
+        bool autostart = parser.isSet(autostartOption);
         bool filename = parser.isSet(filenameOption);
         bool tray = parser.isSet(trayOption);
         bool help = parser.isSet(showHelpOption);
@@ -281,6 +345,21 @@ int main(int argc, char *argv[]) {
         bool someFlagSet = (filename || tray || help ||
                             mainColor || contrastColor);
         ConfigHandler config;
+        if (autostart) {
+            QDBusMessage m = QDBusMessage::createMethodCall("org.dharkael.Flameshot",
+                                               "/", "", "autostartEnabled");
+            if (parser.value(autostartOption) == "false") {
+                m << false;
+            } else if (parser.value(autostartOption) == "true") {
+                m << true;
+            }
+            QDBusConnection sessionBus = QDBusConnection::sessionBus();
+            if (!sessionBus.isConnected()) {
+                SystemNotification().sendMessage(
+                            QObject::tr("Unable to connect via DBus"));
+            }
+            sessionBus.call(m);
+        }
         if (filename) {
             QString newFilename(parser.value(filenameOption));
             config.setFilenamePattern(newFilename);
