@@ -21,13 +21,12 @@
 #include <QDBusConnection>
 #include <QObject>
 
-class DBusUtils : public QObject
-{
+class DBusUtils : public QObject {
     Q_OBJECT
 public:
     explicit DBusUtils(QObject *parent = nullptr);
-    explicit DBusUtils(uint id, QObject *parent = nullptr);
 
+    void connectPrintCapture(QDBusConnection &session, uint id);
     void checkDBusConnection(const QDBusConnection &connection);
 
 public slots:
@@ -35,5 +34,6 @@ public slots:
     void captureFailed(uint id);
 
 private:
+
     uint m_id;
 };
