@@ -20,11 +20,19 @@
 #include <QFileInfo>
 #include <QDir>
 
-QStringList PathInfo::translations() {
-    QString binaryPath = QFileInfo(qApp->applicationFilePath())
+const QString PathInfo::whiteIconPath() {
+    return ":/img/material/white/";
+}
+
+const QString PathInfo::blackIconPath() {
+    return ":/img/material/black/";
+}
+
+QStringList PathInfo::translationsPaths() {
+    QString binaryPath = QFileInfo(qApp->applicationDirPath())
             .absoluteFilePath();
-    QString trPath = QDir::toNativeSeparators(binaryPath) + "translations";
-#if defined(Q_OS_LINUX)
+    QString trPath = QDir::toNativeSeparators(binaryPath + "/translations") ;
+#if defined(Q_OS_LINUX) || defined(Q_OS_UNIX)
     return QStringList()
             << QString(APP_PREFIX) + "/share/flameshot/translations"
             << trPath
