@@ -21,17 +21,17 @@
 
 class QDBusInterface;
 
-class SystemNotification : public QObject
-{
+class SystemNotification : public QObject {
     Q_OBJECT
 public:
     explicit SystemNotification(QObject *parent = nullptr);
 
+    void sendMessage(const QString &text);
+
     void sendMessage(const QString &text,
-                     const QString &title = "Flameshot Info",
+                     const QString &title,
                      const int timeout = 5000);
 
 private:
     QDBusInterface *m_interface;
-
 };
